@@ -126,7 +126,7 @@ class Help(object):
                     log("  {:<24} : {}", spec.name, spec.hint)
                 else:
                     log("  {}", spec.name)
-                log()
+            log()
 
     def describe_task(self, spec):
         if spec.hint:
@@ -160,9 +160,9 @@ class Help(object):
                 if opt.has_value:
                     usage = "%s=%s" % (usage, opt.value_name)
                 if spec.hint:
-                    log("  {:<24} : {}", usage, spec.hint)
+                    log("  {:<24} : {}", usage, opt.hint)
                 else:
-                    log("  {}", spec.name)
+                    log("  {}", opt.name)
             log()
 
     def describe_setting(self, spec):
@@ -192,11 +192,6 @@ class Help(object):
             log()
 
     def describe_topic(self, spec):
-        if spec.hint:
-            log("{} - {}", spec.name.upper(), spec.hint)
-        else:
-            log("{}", spec.name.upper())
-        log()
         if spec.help:
             log(spec.help)
             log()
